Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5029)

Unified Diff: chrome/browser/ui/webui/policy_indicator_localized_strings_provider.h

Issue 1369403006: Add cr-policy-network-indicator and add to internet settings (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Separate policy indicator strings Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/policy_indicator_localized_strings_provider.h
diff --git a/chrome/browser/ui/webui/media_router/media_router_localized_strings_provider.h b/chrome/browser/ui/webui/policy_indicator_localized_strings_provider.h
similarity index 51%
copy from chrome/browser/ui/webui/media_router/media_router_localized_strings_provider.h
copy to chrome/browser/ui/webui/policy_indicator_localized_strings_provider.h
index e700a0ed6e35acc8246da6edc56fba3ff66db650..e448a7384464ec54aea52d08cdb6be78a6cb9396 100644
--- a/chrome/browser/ui/webui/media_router/media_router_localized_strings_provider.h
+++ b/chrome/browser/ui/webui/policy_indicator_localized_strings_provider.h
@@ -2,20 +2,20 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_WEBUI_MEDIA_ROUTER_MEDIA_ROUTER_LOCALIZED_STRINGS_PROVIDER_H_
-#define CHROME_BROWSER_UI_WEBUI_MEDIA_ROUTER_MEDIA_ROUTER_LOCALIZED_STRINGS_PROVIDER_H_
+#ifndef CHROME_BROWSER_UI_WEBUI_POLICY_INDICATOR_LOCALIZED_STRINGS_PROVIDER_H_
+#define CHROME_BROWSER_UI_WEBUI_POLICY_INDICATOR_LOCALIZED_STRINGS_PROVIDER_H_
namespace content {
class WebUIDataSource;
}
-namespace media_router {
+namespace policy_indicator {
-// Adds the strings needed by Media Router to |html_source|. This function
+// Adds the strings needed for policy indicators to |html_source|. This function
// causes |html_source| to expose a strings.js file from its source which
// contains a mapping from string's name to its translated value.
void AddLocalizedStrings(content::WebUIDataSource* html_source);
-} // namespace media_router
+} // namespace policy_indicator
-#endif // CHROME_BROWSER_UI_WEBUI_MEDIA_ROUTER_MEDIA_ROUTER_LOCALIZED_STRINGS_PROVIDER_H_
+#endif // CHROME_BROWSER_UI_WEBUI_POLICY_INDICATOR_LOCALIZED_STRINGS_PROVIDER_H_

Powered by Google App Engine
This is Rietveld 408576698